/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.cat.ui.internal.tabletree;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.swt.custom.CTabFolder;
import org.eclipse.swt.widgets.Display;
import org.eclipse.wst.xml.ui.internal.tabletree.IDesignViewer;
import org.eclipse.wst.xml.ui.internal.tabletree.XMLMultiPageEditorPart;

import benten.cat.ui.CatUiPlugin;
import benten.cat.ui.viewers.TransUnitViewer;
import benten.ui.jobs.BentenSchedulingRule;

/**
 * XLIFF マルチ・ページ・エディター・パーツです。
 * 
 * ★基本設計「翻訳支援機能: 翻訳中間形式エディター機能: 翻訳中間形式(XLIFF)保存」に対応します。
 */
@SuppressWarnings("restriction")
public class XLIFFMultiPageEditorPart extends XMLMultiPageEditorPart {

	/**
	 * コンストラクター。
	 */
	public XLIFFMultiPageEditorPart() {
	}

	@Override
	protected IDesignViewer createDesignPage() {
		return new TransUnitViewer(getContainer(), this);
	}

	@Override
	protected void createPages() {
		super.createPages();
		final CTabFolder tabFolder = (CTabFolder) getContainer();
		tabFolder.getItem(0).setImage(CatUiPlugin.getDefault().getImage("icons/tabtransunit.gif"));
		tabFolder.getItem(1).setImage(CatUiPlugin.getDefault().getImage("icons/tabsource.gif"));
	}

	/**
	 * 保管します。
	 * その他のジョブが実行中の場合はブロックします。
	 */
	@Override
	public void doSave(final IProgressMonitor monitor) {
		final Job job = new Job("XLIFF の保管中...") {
			@Override
			protected IStatus run(final IProgressMonitor monitor) {
				if (monitor.isCanceled()) {
					return Status.CANCEL_STATUS;
				}
				Display.getDefault().syncExec(new Runnable() {
					public void run() {
						XLIFFMultiPageEditorPart.super.doSave(monitor);
					}
				});
				return Status.OK_STATUS;
			}
		};
		job.setUser(true);
		job.setRule(BentenSchedulingRule.INSTANCE);
		job.schedule();
	}
}
